==> qmmp_1.3.1.orig.tar.bz2: qmmp-1.3.1/src/plugins/General/rdetect/translations/rdetect_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>RDetectFactory</name>
    <message>
        <location filename="../rdetectfactory.cpp" line="30"/>
        <source>Volume Detection Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="50"/>
        <source>About Volume Detection Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="51"/>
        <source>Qmmp Removable Volume Detection Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="52"/>
        <source>This plugin provides removable volume detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>RemovableHelper</name>
    <message>
        <location filename="../removablehelper.cpp" line="134"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Voeg CD &quot;%1&quot; toe</translation>
    </message>
    <message>
        <location filename="../removablehelper.cpp" line="138"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Voeg Station &quot;%1&quot; toe</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Volume Detection Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>CD Audio Detectie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Voeg nummers automatisch toe aan speellijst</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Verwijder nummers automatisch uit afspeellijst</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Detectie van Verwisselbare Stations</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Voeg bestanden automatisch toe aan afspeellijst</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Verwijder bestanden automatisch uit afspeellijst</translation>
    </message>
</context>
</TS>

==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/General/rdetect/translations/rdetect_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>RDetectFactory</name>
    <message>
        <location filename="../rdetectfactory.cpp" line="30"/>
        <source>Volume Detection Plugin</source>
        <translation>Externe apparaten-plug-in</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="50"/>
        <source>About Volume Detection Plugin</source>
        <translation>Over de Externe apparaten-plug-in</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="51"/>
        <source>Qmmp Removable Volume Detection Plugin</source>
        <translation>Externe apparaten-plug-in voor Qmmp</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="52"/>
        <source>This plugin provides removable volume detection</source>
        <translation>Deze module faciliteert detectie van verwisselbare apparaten</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>RemovableHelper</name>
    <message>
        <location filename="../removablehelper.cpp" line="134"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Voeg CD &quot;%1&quot; toe</translation>
    </message>
    <message>
        <location filename="../removablehelper.cpp" line="138"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Voeg Station &quot;%1&quot; toe</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Volume Detection Plugin Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>CD Audio Detectie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Voeg nummers automatisch toe aan speellijst</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Verwijder nummers automatisch uit afspeellijst</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Detectie van Verwisselbare Stations</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Voeg bestanden automatisch toe aan afspeellijst</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Verwijder bestanden automatisch uit afspeellijst</translation>
    </message>
</context>
</TS>
